fn validate_if(
key: &Token,
block: &Block,
data: &Everything,
sc: &mut ScopeContext,
check_desc: bool,
)Expand description
Validate if or else_if blocks that are part of a script value.
Checks the limit field and then relies on validate_inner for the heavy lifting.