fn validate_inner(
vd: Validator<'_>,
block: &Block,
data: &Everything,
sc: &mut ScopeContext,
have_value: TriBool,
check_desc: bool,
) -> boolExpand description
Validate a block that’s part of a script value.
have_value: indicates whether this script value has had some sort of value set already. It’s used to emit warnings when overwriting this value, or when assuming there is a value when there isn’t one. Has valuesTrue,False, orMaybe.check_desc: indicates whether localization errors are worth warning about. Some script values only have their breakdowns displayed while debugging, and those can have raw (non-localized) text in their descs.
Returns true iff this block did something useful. (Used for warnings)